@@ -1,8 +1,8 @@
 from re import search
+from tkinter import Listbox
 
-from discord import Embed, Message
+from discord import Embed, Message, Interaction
 from discord.ext import commands
-from discord.abc import Messageable
 
 from pycordViews import EasyModifiedViews
 
@@ -42,7 +42,10 @@ async def dshell_send_message(ctx: Message, message=None, delete=None, channel=N
     if not isinstance(embeds, (ListNode, Embed, NoneType)):
         raise Exception(f'Embeds must be a list of Embed objects or a single Embed object, not {type(embeds)} !')
 
-    if isinstance(embeds, Embed):
+    if embeds is None:
+        embeds = ListNode([])
+
+    elif isinstance(embeds, Embed):
         embeds = ListNode([embeds])
 
     if not isinstance(view, (EasyModifiedViews, NoneType)):
@@ -68,15 +71,15 @@ async def dshell_respond_message(ctx: Message, message=None, content: str = None
 
     from .._DshellParser.ast_nodes import ListNode
 
+    if not isinstance(embeds, (ListNode, Embed, NoneType)):
+        raise Exception(f'Embeds must be a list of Embed objects or a single Embed object, not {type(embeds)} !')
+
     if embeds is None:
         embeds = ListNode([])
 
     elif isinstance(embeds, Embed):
         embeds = ListNode([embeds])
 
-    else:
-        raise Exception(f'Embeds must be a list of Embed objects or a single Embed object, not {type(embeds)} !')
-
     sended_message = await respond_message.reply(
                                      content=str(content),
                                      mention_author=mention_author,
@@ -117,24 +120,32 @@ async def dshell_purge_message(ctx: Message, message_number: int, channel=None,
     await purge_channel.purge(limit=message_number, reason=reason)
 
 
-async def dshell_edit_message(ctx: Message, message, new_content=None, embeds=None):
+async def dshell_edit_message(ctx: Message, message, new_content=None, embeds=None, view=None) -> int:
     """
     Edits a message
     """
     edit_message = utils_get_message(ctx, message)
 
+    from .._DshellParser.ast_nodes import ListNode
+
+    if not isinstance(embeds, (ListNode, Embed, NoneType)):
+        raise Exception(f'Embeds must be a list of Embed objects or a single Embed object, not {type(embeds)} !')
+
+    if not isinstance(view, (EasyModifiedViews, NoneType)):
+        raise Exception(f'View must be an UI bloc or None, not {type(view)} !')
+
     if embeds is None:
-        embeds = []
+        embeds = ListNode([])
 
     elif isinstance(embeds, Embed):
-        embeds = [embeds]
+        embeds = ListNode([embeds])
 
-    await edit_message.edit(content=new_content, embeds=embeds)
+    await edit_message.edit(content=new_content, embeds=embeds, view=view)
 
     return edit_message.id
 
 
-async def dshell_get_hystory_messages(ctx: Message, channel=None, limit=None):
+async def dshell_get_hystory_messages(ctx: Message, channel=None, limit=None) -> "ListNode":
     """
     Searches for messages matching a regex in a channel
     """
