@@ -15,6 +15,7 @@ from ..DISCORD_COMMANDS.dshell_member import *
 from ..DISCORD_COMMANDS.dshell_message import *
 from ..DISCORD_COMMANDS.dshell_pastbin import *
 from ..DISCORD_COMMANDS.dshell_role import *
+from ..DISCORD_COMMANDS.dshell_interaction import *
 
 dshell_keyword: set[str] = {
     'if', 'else', 'elif', 'loop', '#end', 'var', '#loop', '#if', 'sleep', 'param', '#param'
@@ -34,6 +35,9 @@ dshell_commands: dict[str, Callable] = {
     "pm": dshell_purge_message,
     "em": dshell_edit_message,  # edit message
 
+    "sri": dshell_respond_interaction,  # respond to an interaction
+    "di": dshell_defer_interaction,  # defer an interaction
+
     "cc": dshell_create_text_channel,  # create channel
     "cvc": dshell_create_voice_channel,  # create voice channel
     "dc": dshell_delete_channel,  # delete channel
